@@ -5,10 +5,10 @@ from typing import Callable, List, Union
 import numpy as np
 
 from continuum.datasets import _ContinuumDataset
-from continuum.scenarios import _BaseCLLoader
+from continuum.scenarios import _BaseScenario
 
 
-class ClassIncremental(_BaseCLLoader):
+class ClassIncremental(_BaseScenario):
     """Continual Loader, generating datasets for the consecutive tasks.
 
     Scenario: Each new tasks bring new classes only
@@ -22,6 +22,7 @@ class ClassIncremental(_BaseCLLoader):
                               Desactivated if `increment` is a list.
     :param transformations: A list of transformations applied to all tasks.
     :param class_order: An optional custom class order, used for NC.
+                        e.g. [0,1,2,3,4,5,6,7,8,9] or [5,2,4,1,8,6,7,9,0,3]
     """
 
     def __init__(
@@ -31,7 +32,7 @@ class ClassIncremental(_BaseCLLoader):
         increment: Union[List[int], int] = 0,
         initial_increment: int = 0,
         transformations: List[Callable] = None,
-        class_order=None
+        class_order: Union[List[int], None]=None
     ) -> None:
 
         super().__init__(cl_dataset=cl_dataset, nb_tasks=nb_tasks, transformations=transformations)
@@ -117,7 +118,7 @@ class ClassIncremental(_BaseCLLoader):
                 raise Exception("The increment list is not compatible with the number of classes")
 
             increments = increment
-        else:
+        elif isinstance(increment, int) and increment > 0:
             increments = []
             if initial_increment:
                 increments.append(initial_increment)
@@ -129,6 +130,8 @@ class ClassIncremental(_BaseCLLoader):
                     f" with {len(self.class_order)} and increment {increment}"
                 )
             increments.extend([increment for _ in range(int(nb_tasks))])
+        else:
+            raise TypeError(f"Invalid increment={increment}, it must be an int > 0.")
 
         return increments
 
